"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactTestingLibrary = require("react-testing-library");

var _factoryGirl = require("factory-girl");

var _testContextProvider = _interopRequireDefault(require("../spec/test-context-provider"));

var _propertyHeader = _interopRequireDefault(require("./property-header"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

require('../../../../spec/fixtures/resource.factory');

require('jsdom-global')();

describe('PropertyHeader', function () {
  this.timeout(5000);
  const location = {
    search: ''
  };
  beforeEach(async function () {
    this.resource = await _factoryGirl.factory.build('resource');
    this.property = await _factoryGirl.factory.build('property', {
      isSortable: true
    });
    this.resource.listProperties.push(this.property);
  });
  context('render not selected but searchable field', function () {
    beforeEach(async function () {
      this.sortBy = 'otherProperty';
      this.direction = 'desc';
      const {
        findAllByText,
        container
      } = (0, _reactTestingLibrary.render)(_react.default.createElement(_testContextProvider.default, null, _react.default.createElement(_propertyHeader.default, {
        property: this.property,
        resource: this.resource,
        location: location,
        sortBy: this.sortBy,
        direction: this.direction
      })));
      this.findAllByText = findAllByText;
      this.container = container;
    });
    it('renders a label', async function () {
      const label = await this.findAllByText(this.property.label);
      expect(label).to.have.lengthOf(1);
    });
    it('wraps it within a link with an opposite direction', function () {
      const href = this.container.querySelector('a').getAttribute('href');
      const query = new URLSearchParams(href.replace('/?', ''));
      expect(query.get('direction')).to.equal('asc');
      expect(query.get('sortBy')).to.equal(this.property.name);
    });
    it('doesn\t render a sort indicator', function () {
      expect(this.container.querySelector('i')).to.be.null;
    });
  });
  context('selected and searchable field', function () {
    beforeEach(async function () {
      this.sortBy = this.property.name;
      this.direction = 'asc';
      const {
        findAllByText,
        container
      } = (0, _reactTestingLibrary.render)(_react.default.createElement(_testContextProvider.default, null, _react.default.createElement(_propertyHeader.default, {
        property: this.property,
        resource: this.resource,
        location: location,
        sortBy: this.sortBy,
        direction: this.direction
      })));
      this.findAllByText = findAllByText;
      this.container = container;
    });
    it('renders a sort indicator', function () {
      const icon = this.container.querySelector('i');
      expect(icon).not.to.be.null;
      expect(icon.classList['0']).to.equal('icomoon-dropdown-open');
    });
  });
});